@@ -14,14 +14,15 @@ Math::Symbolic::Compiler - Compile Math::Symbolic trees to Perl code
   my $vars = [a => 1, b => 0, c => 2];
   
   my ($closure, $code, $trees) =
-          Math::Symbolic::Compiler->compile($tree, $vars);
+    Math::Symbolic::Compiler->compile($tree, $vars);
   
   print $closure->(2, 3, 5); # (b, a, c)
   # prints 34 (=2^2 + 3*5*2)
   
   # or:
   ($closure, $trees) =
-          Math::Symbolic::Compiler->compile_to_sub($tree, $vars);
+    Math::Symbolic::Compiler->compile_to_sub($tree, $vars);
+  
   ($code, $trees) = Math::Symbolic::Compiler->compile_to_code($tree, $vars);
 
 =head1 DESCRIPTION
@@ -82,18 +83,21 @@ use Math::Symbolic::ExportConstants qw/:all/;
 
 our @ISA = qw(Exporter);
 
-our %EXPORT_TAGS = ( 'all' => [ qw(
-	&compile
-	&compile_to_sub
-	&compile_to_code
-) ] );
+our %EXPORT_TAGS = (
+    'all' => [
+        qw(
+          &compile
+          &compile_to_sub
+          &compile_to_code
+          )
+    ]
+);
 
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 
 our @EXPORT = qw();
 
-our $VERSION = '0.114';
-
+our $VERSION = '0.115';
 
 =head2 ($code, $trees) = compile_to_code($tree, $vars)
 
@@ -118,48 +122,47 @@ that is slow.
 =cut
 
 sub compile_to_code {
-	my $tree = shift;
-	$tree = shift if $tree eq __PACKAGE__;
+    my $tree = shift;
+    $tree = shift if $tree eq __PACKAGE__;
 
-	my $order = shift || [];
-	my $count = 0;
-	my %order = map {($_, $count++)} @$order;
+    my $order = shift || [];
+    my $count = 0;
+    my %order = map { ( $_, $count++ ) } @$order;
 
-	no warnings 'recursion';
-	
-	my $vars = _find_vars($tree);
+    no warnings 'recursion';
 
-	my %vars;
-	my @not_placed;
-	foreach (@$vars) {
-		my $pos = $order{$_};
-		if (defined $pos) {
-			$vars{$_} = $pos;
-		}
-		else {
-			push @not_placed, $_;
-		}
-	}
-	
-	$count = 0;
-	foreach (sort @not_placed) {
-		$vars{$_} = @$vars - @not_placed + $count++;
-	}
+    my $vars = _find_vars($tree);
 
-	# The user is to do that himself.
-#	$tree = $tree->simplify();
-#	$tree = $tree->apply_derivatives();
-#	$tree = $tree->simplify();
-	
-	my @trees;
-	
-	my $code = _rec_ms_to_sub($tree, \%vars, \@trees);
+    my %vars;
+    my @not_placed;
+    foreach (@$vars) {
+        my $pos = $order{$_};
+        if ( defined $pos ) {
+            $vars{$_} = $pos;
+        }
+        else {
+            push @not_placed, $_;
+        }
+    }
 
-	return($code, \@trees);
+    $count = 0;
+    foreach ( sort @not_placed ) {
+        $vars{$_} = @$vars - @not_placed + $count++;
+    }
+
+    # The user is to do that himself. Left in to show that it would be
+    # a sensible (if slow) thing to do.
+    # $tree = $tree->simplify();
+    # $tree = $tree->apply_derivatives();
+    # $tree = $tree->simplify();
+
+    my @trees;
+
+    my $code = _rec_ms_to_sub( $tree, \%vars, \@trees );
+
+    return ( $code, \@trees );
 }
 
-
-
 =head2 ($sub, $trees) = compile_to_sub($tree, $vars)
 
 The compile_to_sub() class method takes one mandatory argument which is
@@ -173,15 +176,12 @@ the docs on the compile_to_code() subroutine.
 
 =cut
 
-
 sub compile_to_sub {
-	my ($code, $trees) = Math::Symbolic::Compiler::compile_to_code(@_);
-	my $sub = _compile_sub('sub {' . $code . '}', @$trees);
-	return ($sub, $trees);
+    my ( $code, $trees ) = Math::Symbolic::Compiler::compile_to_code(@_);
+    my $sub = _compile_sub( 'sub {' . $code . '}', @$trees );
+    return ( $sub, $trees );
 }
 
-
-
 =head2 ($sub, $code, $trees) = compile($tree, $vars)
 
 The compile() class method takes one mandatory argument which is
@@ -197,96 +197,82 @@ subroutine.
 =cut
 
 sub compile {
-	my ($code, $trees) = Math::Symbolic::Compiler::compile_to_code(@_);
-	my $sub = _compile_sub('sub {' . $code . '}', @$trees);
-	return ($sub, $code, $trees);
+    my ( $code, $trees ) = Math::Symbolic::Compiler::compile_to_code(@_);
+    my $sub = _compile_sub( 'sub {' . $code . '}', @$trees );
+    return ( $sub, $code, $trees );
 }
 
-
 sub _compile_sub {
-	my @_TREES;
-	@_TREES = @_[1..$#_] if @_>1;
-	my $sub = eval $_[0];
-	die "$@" if $@;
-	return $sub;
+    my @_TREES;
+    @_TREES = @_[ 1 .. $#_ ] if @_ > 1;
+    my $sub = eval $_[0];
+    die "$@" if $@;
+    return $sub;
 }
 
 sub _rec_ms_to_sub {
-	my $tree  = shift;
-	my $vars  = shift;
-	my $trees = shift;
+    my $tree  = shift;
+    my $vars  = shift;
+    my $trees = shift;
 
-	my $code = '';
-	my $ttype = $tree->term_type();
-	
-	if ($ttype == T_CONSTANT) {
-		$code .= $tree->value();
-	}
-	elsif ($ttype == T_VARIABLE) {
-		$code .= '$_[' . $vars->{ $tree->name() } . ']';
-	}
-	else {
-		my $type = $tree->type();
-		my $otype = $Math::Symbolic::Operator::Op_Types[$type];
-		my $app = $otype->{application};
-		if (ref($app) eq 'CODE') {
-			push @$trees, $tree->new();
-			my $arg_str =
-				join ', ',
-				map {"'$_' => \$_[" . $vars->{$_} . ']'}
-				keys %$vars;
-			my $index = $#$trees;
-			$code .= <<HERE
+    my $code  = '';
+    my $ttype = $tree->term_type();
+
+    if ( $ttype == T_CONSTANT ) {
+        $code .= $tree->value();
+    }
+    elsif ( $ttype == T_VARIABLE ) {
+        $code .= '$_[' . $vars->{ $tree->name() } . ']';
+    }
+    else {
+        my $type  = $tree->type();
+        my $otype = $Math::Symbolic::Operator::Op_Types[$type];
+        my $app   = $otype->{application};
+        if ( ref($app) eq 'CODE' ) {
+            push @$trees, $tree->new();
+            my $arg_str = join( ', ',
+                map { "'$_' => \$_[" . $vars->{$_} . ']' } keys %$vars );
+            my $index = $#$trees;
+            $code .= <<HERE
 (\$_TREES[$index]->value($arg_str))
 HERE
-		}
-		else {
-			my @app = split /\$_\[(\d+)\]/, $app;
-			if (@app > 1) {
-				for (my $i = 1; $i < @app; $i+=2) {
-					$app[$i] =
-					'(' .
-					_rec_ms_to_sub(
-						$tree->{operands}[$app[$i]],
-						$vars,
-						$trees
-					) .
-					')';
-				}
-			}
-			$code .= join '', @app;
-		}
-	}
-	return $code;
+        }
+        else {
+            my @app = split /\$_\[(\d+)\]/, $app;
+            if ( @app > 1 ) {
+                for ( my $i = 1 ; $i < @app ; $i += 2 ) {
+                    $app[$i] = '('
+                      . _rec_ms_to_sub( $tree->{operands}[ $app[$i] ],
+                        $vars, $trees )
+                      . ')';
+                }
+            }
+            $code .= join '', @app;
+        }
+    }
+    return $code;
 }
 
-
 sub _find_vars {
-	my $tree = shift;
-	my $ttype = $tree->term_type();
-	my $vars = [];
-	if ($ttype == T_VARIABLE) {
-		push @$vars, $tree->name();
-	}
-	elsif ($ttype == T_OPERATOR) {
-		my $type = $tree->type();
-		my $otype = $Math::Symbolic::Operator::Op_Types[$type];
-		my %v = map {($_, undef)} @$vars;
-		foreach (0..@{$tree->{operands}}-1) {
-			my $v = _find_vars($tree->{operands}[$_]);
-			foreach (@$v) {
-				$v{$_} = undef;
-			}
-		}
-		$vars = [keys %v];
-	}
-	return $vars;
+    my $tree  = shift;
+    my $ttype = $tree->term_type();
+    my $vars  = [];
+    if ( $ttype == T_VARIABLE ) {
+        push @$vars, $tree->name();
+    }
+    elsif ( $ttype == T_OPERATOR ) {
+        my $type  = $tree->type();
+        my $otype = $Math::Symbolic::Operator::Op_Types[$type];
+        my %v     = map { ( $_, undef ) } @$vars;
+        foreach ( 0 .. @{ $tree->{operands} } - 1 ) {
+            my $v = _find_vars( $tree->{operands}[$_] );
+            $v{$_} = undef foreach @$v;
+        }
+        $vars = [ keys %v ];
+    }
+    return $vars;
 }
 
-
-
-
-
 1;
 __END__
 
@@ -310,9 +296,8 @@ compile_* functions found in this package. This second argument is expected
 to be an array of key/value pairs with the keys being variable names and the
 values being their position starting from 0. Example:
 
-  my ($sub) = Math::Symbolic::Compiler->compile_to_sub(
-                    $tree, [b => 2, c => 0, a => 1]
-              );
+  my ($sub) =
+    Math::Symbolic::Compiler->compile_to_sub($tree, [b => 2, c => 0, a => 1]);
     
   # First argument will be mapped to c, second to a, and third to b
   # All others will be ignored.
@@ -327,12 +312,26 @@ yourself, they will be sorted lexicographically.
 
 =head1 AUTHOR
 
-Steffen Mueller, E<lt>symbolic-module at steffen-mueller dot netE<gt>
+Please send feedback, bug reports, and support requests to the Math::Symbolic
+support mailing list:
+math-symbolic-support at lists dot sourceforge dot net. Please
+consider letting us know how you use Math::Symbolic. Thank you.
 
-New versions of this module can be found on http://steffen-mueller.net or CPAN.
+If you're interested in helping with the development or extending the
+module's functionality, please contact the developer's mailing list:
+math-symbolic-develop at lists dot sourceforge dot net.
+
+List of contributors:
+
+  Steffen Mller, symbolic-module at steffen-mueller dot net
+  Stray Toaster, mwk at users dot sourceforge dot net
 
 =head1 SEE ALSO
 
+New versions of this module can be found on
+http://steffen-mueller.net or CPAN. The module development takes place on
+Sourceforge at http://sourceforge.net/projects/math-symbolic/
+
 L<Math::Symbolic>
 
 =cut
