@@ -1,3 +1,4 @@
+
 =head1 NAME
 
 Math::Symbolic::Custom::Base - Base class for tree tests and transformations
@@ -50,30 +51,43 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.114';
+our $VERSION = '0.115';
 our $AUTOLOAD;
 
 sub aggregate_import {
-	my $class = shift;
-	no strict 'refs';
-	my $subs = ${"${class}::Aggregate_Export"};
-	foreach my $sub (@$subs) {
-		*{"Math::Symbolic::Custom::$sub"} = \&{"$class\:\:$sub"};
-	}
+    my $class = shift;
+    no strict 'refs';
+    my $subs = ${"${class}::Aggregate_Export"};
+    foreach my $sub (@$subs) {
+        *{"Math::Symbolic::Custom::$sub"} = \&{"$class\:\:$sub"};
+    }
 }
 
-
 1;
 __END__
 
 =head1 AUTHOR
 
-Steffen Mueller, E<lt>symbolic-module at steffen-mueller dot netE<gt>
+Please send feedback, bug reports, and support requests to the Math::Symbolic
+support mailing list:
+math-symbolic-support at lists dot sourceforge dot net. Please
+consider letting us know how you use Math::Symbolic. Thank you.
 
-New versions of this module can be found on http://steffen-mueller.net or CPAN.
+If you're interested in helping with the development or extending the
+module's functionality, please contact the developer's mailing list:
+math-symbolic-develop at lists dot sourceforge dot net.
+
+List of contributors:
+
+  Steffen Mller, symbolic-module at steffen-mueller dot net
+  Stray Toaster, mwk at users dot sourceforge dot net
 
 =head1 SEE ALSO
 
+New versions of this module can be found on
+http://steffen-mueller.net or CPAN. The module development takes place on
+Sourceforge at http://sourceforge.net/projects/math-symbolic/
+
 L<Math::Symbolic>
 
 =cut
