@@ -8,18 +8,17 @@ use Data::Dumper;
 use Math::Symbolic qw/:all/;
 
 my $var = Math::Symbolic::Variable->new();
-my $a = $var->new('a' => 2);
+my $a   = $var->new( 'a' => 2 );
 
-print "Vars: a=" . $a->value() .
-           " (Value is optional)\n\n";
+print "Vars: a=" . $a->value() . " (Value is optional)\n\n";
 
 my $const = Math::Symbolic::Constant->new();
 my $ten   = $const->new(10);
 
 my $op   = Math::Symbolic::Operator->new();
-my $mul1 = $op->new('*', $a, $a);
+my $mul1 = $op->new( '*', $a, $a );
 
-my $exp = $op->new('^', $ten, $mul1);
+my $exp = $op->new( '^', $ten, $mul1 );
 
 print "Expression: 10^(a*a)\n\n";
 
@@ -28,10 +27,12 @@ print $exp->to_string('prefix') . " = " . $exp->value() . "\n\n";
 
 print "Now, we derive this partially to a: (prefix again)\n";
 
-my $n_tree = $op->new( {
-	type => U_P_DERIVATIVE,
-	operands => [$exp, $a],
-} );
+my $n_tree = $op->new(
+    {
+        type     => U_P_DERIVATIVE,
+        operands => [ $exp, $a ],
+    }
+);
 
 print $n_tree->to_string('prefix') . " = " . $n_tree->value() . "\n\n";
 
